==> react-native-web-jsonschema-form-1.0.6.tgz: package/widgets/TextInputWidget.js <==
import _withHandlers from "recompact/withHandlers";
import _isString from "lodash/isString";
import _noop from "lodash/noop";
import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet, Platform } from 'react-native';
import TextInput from 'react-native-web-ui-components/TextInput';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import { formatMask } from '../utils';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});

const TextInputWidget = _withHandlers({
  onWrappedFocus: ({
    name,
    onFocus
  }) => () => onFocus(name),
  onWrappedChange: ({
    name,
    mask,
    onChange,
    textParser
  }) => text => {
    if (!mask) {
      return onChange(textParser(text), name);
    }

    if (typeof mask === 'function') {
      return onChange(textParser(mask(text)), name);
    }

    return onChange(textParser(formatMask(text, mask)), name);
  }
})(({
  uiSchema,
  hasError,
  onSubmit,
  name,
  focus,
  value,
  readonly,
  disabled,
  secureTextEntry,
  placeholder,
  mask,
  keyboardType,
  multiline,
  numberOfLines,
  auto,
  onChange,
  onWrappedChange,
  onWrappedFocus,
  textParser,
  ...props
}) => {
  if (mask && _isString(mask) && value !== null && value !== undefined) {
    const maskedValue = textParser(formatMask(value, mask));

    if (value !== maskedValue) {
      setTimeout(() => onChange(maskedValue, name, {
        silent: true
      }));
    }
  }

  const currentStyle = [styles.defaults, auto ? styles.auto : styles.fullWidth, props.style];
  const focused = focus === name || focus === null && uiSchema['ui:autofocus'];
  return React.createElement(TextInput, {
    hasError: hasError,
    disabled: disabled,
    readonly: readonly,
    autoCapitalize: "none",
    className: "text-widget",
    style: currentStyle,
    onFocus: onWrappedFocus,
    onSubmitEditing: multiline ? _noop : onSubmit,
    onChangeText: onWrappedChange,
    autoFocus: focused,
    multiline: multiline,
    numberOfLines: numberOfLines,
    keyboardType: Platform.OS !== 'web' ? keyboardType : undefined,
    value: (value !== undefined && value !== null ? `${value}` : '') || uiSchema['ui:emptyValue'] || '',
    placeholder: placeholder,
    secureTextEntry: secureTextEntry
  });
});

TextInputWidget.propTypes = {
  name: PropTypes.string.isRequired,
  uiSchema: PropTypes.shape({}).isRequired,
  hasError: PropTypes.bool.isRequired,
  style: StylePropType,
  mask: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  onFocus: PropTypes.func,
  onChange: PropTypes.func,
  onSubmit: PropTypes.func,
  focus: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  placeholder: PropTypes.string,
  readonly: PropTypes.bool,
  disabled: PropTypes.bool,
  secureTextEntry: PropTypes.bool,
  keyboardType: PropTypes.string,
  multiline: PropTypes.bool,
  numberOfLines: PropTypes.number,
  auto: PropTypes.bool,
  textParser: PropTypes.func
};
TextInputWidget.defaultProps = {
  style: styles.empty,
  mask: null,
  onFocus: _noop,
  onChange: _noop,
  onSubmit: _noop,
  focus: null,
  value: null,
  placeholder: '',
  readonly: false,
  disabled: false,
  secureTextEntry: false,
  keyboardType: 'default',
  multiline: false,
  numberOfLines: 1,
  auto: false,
  textParser: value => value
};
export default TextInputWidget;

==> react-native-web-jsonschema-form-1.0.28.tgz: package/widgets/TextInputWidget.js <==
import _withHandlers from "recompact/withHandlers";
import _isFunction from "lodash/isFunction";
import _isString from "lodash/isString";
import _noop from "lodash/noop";
import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet, Platform } from 'react-native';
import TextInput from 'react-native-web-ui-components/TextInput';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import { formatMask } from '../utils';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});

const TextInputWidget = _withHandlers({
  onWrappedFocus: ({
    name,
    onFocus
  }) => () => onFocus(name),
  onWrappedChange: ({
    name,
    mask,
    onChange,
    textParser
  }) => text => {
    if (!mask) {
      return onChange(textParser(text), name);
    }

    if (_isFunction(mask)) {
      return onChange(textParser(mask(text, 'out')), name);
    }

    return onChange(textParser(formatMask(text, mask)), name);
  }
})(({
  uiSchema,
  hasError,
  onSubmit,
  name,
  focus,
  value,
  readonly,
  disabled,
  secureTextEntry,
  placeholder,
  mask,
  keyboardType,
  multiline,
  numberOfLines,
  auto,
  onChange,
  onWrappedChange,
  onWrappedFocus,
  textParser,
  ...props
}) => {
  let textValue = '';

  if (value !== null && value !== undefined) {
    if (_isString(mask)) {
      textValue = formatMask(`${value}`, mask);
    } else if (_isFunction(mask)) {
      textValue = mask(`${value}`, 'in');
    } else {
      textValue = value;
    }

    if (mask) {
      const maskedValue = textParser(textValue);

      if (value !== maskedValue) {
        setTimeout(() => onChange(maskedValue, name, {
          silent: true
        }));
      }
    }
  }

  const currentStyle = [styles.defaults, auto ? styles.auto : styles.fullWidth, props.style];
  const focused = focus === name || focus === null && uiSchema['ui:autofocus'];
  return React.createElement(TextInput, {
    hasError: hasError,
    disabled: disabled,
    readonly: readonly,
    autoCapitalize: "none",
    className: "text-widget",
    style: currentStyle,
    onFocus: onWrappedFocus,
    onSubmitEditing: multiline ? _noop : onSubmit,
    onChangeText: onWrappedChange,
    autoFocus: focused,
    multiline: multiline,
    numberOfLines: numberOfLines,
    keyboardType: Platform.OS !== 'web' ? keyboardType : undefined,
    value: textValue || uiSchema['ui:emptyValue'] || '',
    placeholder: placeholder,
    secureTextEntry: secureTextEntry
  });
});

TextInputWidget.propTypes = {
  name: PropTypes.string.isRequired,
  uiSchema: PropTypes.shape({}).isRequired,
  hasError: PropTypes.bool.isRequired,
  style: StylePropType,
  mask: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  onFocus: PropTypes.func,
  onChange: PropTypes.func,
  onSubmit: PropTypes.func,
  focus: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  placeholder: PropTypes.string,
  readonly: PropTypes.bool,
  disabled: PropTypes.bool,
  secureTextEntry: PropTypes.bool,
  keyboardType: PropTypes.string,
  multiline: PropTypes.bool,
  numberOfLines: PropTypes.number,
  auto: PropTypes.bool,
  textParser: PropTypes.func
};
TextInputWidget.defaultProps = {
  style: styles.empty,
  mask: null,
  onFocus: _noop,
  onChange: _noop,
  onSubmit: _noop,
  focus: null,
  value: null,
  placeholder: '',
  readonly: false,
  disabled: false,
  secureTextEntry: false,
  keyboardType: 'default',
  multiline: false,
  numberOfLines: 1,
  auto: false,
  textParser: value => value
};
export default TextInputWidget;
